@@ -1,5 +1,3 @@
-# -*- coding:utf-8 -*-
-
 # Copyright (c) 2009-2018 - Simon Conseil
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -20,20 +18,18 @@
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 
-from __future__ import absolute_import, print_function
-
 import click
 import importlib
-import io
 import locale
 import logging
 import os
+import socketserver
 import sys
 import time
 
 from click import argument, option
+from http import server
 
-from .compat import server, socketserver, string_types
 from .gallery import Gallery
 from .log import init_logging
 from .pkgmeta import __version__
@@ -42,6 +38,9 @@ from .utils import copy
 
 _DEFAULT_CONFIG_FILE = 'sigal.conf.py'
 
+if sys.version_info[:2] < (3, 5):
+    raise Exception('Sigal supports Python 3.5+ only')
+
 
 @click.group()
 @click.version_option(version=__version__)
@@ -68,7 +67,7 @@ def init(path):
     from pkg_resources import resource_string
     conf = resource_string(__name__, 'templates/sigal.conf.py')
 
-    with io.open(path, 'w', encoding='utf-8') as f:
+    with open(path, 'w', encoding='utf-8') as f:
         f.write(conf.decode('utf8'))
     print("Sample config file created: {}".format(path))
 
@@ -173,7 +172,7 @@ def init_plugins(settings):
 
     for plugin in settings['plugins']:
         try:
-            if isinstance(plugin, string_types):
+            if isinstance(plugin, str):
                 mod = importlib.import_module(plugin)
                 mod.register(settings)
             else:
@@ -255,7 +254,7 @@ def set_meta(target, keys, overwrite=False):
         sys.exit(2)
 
     with open(descfile, "w") as fp:
-        for i in range(len(keys)//2):
-            k, v = keys[i*2:(i+1)*2]
+        for i in range(len(keys) // 2):
+            k, v = keys[i * 2:(i + 1) * 2]
             fp.write("{}: {}\n".format(k.capitalize(), v))
-    print("{} metadata key(s) written to {}".format(len(keys)//2, descfile))
+    print("{} metadata key(s) written to {}".format(len(keys) // 2, descfile))
